@@ -460,12 +460,12 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.core
-import constructs
+import aws_cdk.core as _aws_cdk_core_f4b25747
+import constructs as _constructs_77d1e7e8
 
 
 class CfnInclude(
-    aws_cdk.core.CfnElement,
+    _aws_cdk_core_f4b25747.CfnElement,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/cloudformation-include.CfnInclude",
 ):
@@ -485,11 +485,11 @@ class CfnInclude(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[builtins.str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -502,17 +502,7 @@ class CfnInclude(
         :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                template_file: builtins.str,
-                load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[str, typing.Any]]]] = None,
-                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
-                preserve_logical_ids: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2f3bb4e628f0f7d9dc75fd726d376ac771922ab3819ff8f99c9ddb68dd59f12d)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnIncludeProps(
@@ -525,7 +515,10 @@ class CfnInclude(
         jsii.create(self.__class__, self, [scope, id, props])
 
     @jsii.member(jsii_name="getCondition")
-    def get_condition(self, condition_name: builtins.str) -> aws_cdk.core.CfnCondition:
+    def get_condition(
+        self,
+        condition_name: builtins.str,
+    ) -> _aws_cdk_core_f4b25747.CfnCondition:
         '''Returns the CfnCondition object from the 'Conditions' section of the CloudFormation template with the given name.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -536,14 +529,12 @@ class CfnInclude(
         :param condition_name: the name of the Condition in the CloudFormation template file.
         '''
         if __debug__:
-            def stub(condition_name: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1f5a0c7f41eaa1a8f191291aa9de40c89d46ac733246c896e86e480269324f97)
             check_type(argname="argument condition_name", value=condition_name, expected_type=type_hints["condition_name"])
-        return typing.cast(aws_cdk.core.CfnCondition, jsii.invoke(self, "getCondition", [condition_name]))
+        return typing.cast(_aws_cdk_core_f4b25747.CfnCondition, jsii.invoke(self, "getCondition", [condition_name]))
 
     @jsii.member(jsii_name="getHook")
-    def get_hook(self, hook_logical_id: builtins.str) -> aws_cdk.core.CfnHook:
+    def get_hook(self, hook_logical_id: builtins.str) -> _aws_cdk_core_f4b25747.CfnHook:
         '''Returns the CfnHook object from the 'Hooks' section of the included CloudFormation template with the given logical ID.
 
         Any modifications performed on the returned object will be reflected in the resulting CDK template.
@@ -554,14 +545,15 @@ class CfnInclude(
         :param hook_logical_id: the logical ID of the Hook in the included CloudFormation template's 'Hooks' section.
         '''
         if __debug__:
-            def stub(hook_logical_id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__35991c2bf1db192aae4fc779c6651fae41c9f8fba40faebafd3294897a859c65)
             check_type(argname="argument hook_logical_id", value=hook_logical_id, expected_type=type_hints["hook_logical_id"])
-        return typing.cast(aws_cdk.core.CfnHook, jsii.invoke(self, "getHook", [hook_logical_id]))
+        return typing.cast(_aws_cdk_core_f4b25747.CfnHook, jsii.invoke(self, "getHook", [hook_logical_id]))
 
     @jsii.member(jsii_name="getMapping")
-    def get_mapping(self, mapping_name: builtins.str) -> aws_cdk.core.CfnMapping:
+    def get_mapping(
+        self,
+        mapping_name: builtins.str,
+    ) -> _aws_cdk_core_f4b25747.CfnMapping:
         '''Returns the CfnMapping object from the 'Mappings' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -572,11 +564,9 @@ class CfnInclude(
         :param mapping_name: the name of the Mapping in the template to retrieve.
         '''
         if __debug__:
-            def stub(mapping_name: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0f696ec50b8ce04c683df8ddfd925f5b0ffce9afb6ec36455ec2b0aca689f501)
             check_type(argname="argument mapping_name", value=mapping_name, expected_type=type_hints["mapping_name"])
-        return typing.cast(aws_cdk.core.CfnMapping, jsii.invoke(self, "getMapping", [mapping_name]))
+        return typing.cast(_aws_cdk_core_f4b25747.CfnMapping, jsii.invoke(self, "getMapping", [mapping_name]))
 
     @jsii.member(jsii_name="getNestedStack")
     def get_nested_stack(self, logical_id: builtins.str) -> "IncludedNestedStack":
@@ -589,14 +579,12 @@ class CfnInclude(
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
         '''
         if __debug__:
-            def stub(logical_id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f03477ec6b0fd7fb319f4bc742a91b8f1834203a87e61e19a049e71c55252915)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast("IncludedNestedStack", jsii.invoke(self, "getNestedStack", [logical_id]))
 
     @jsii.member(jsii_name="getOutput")
-    def get_output(self, logical_id: builtins.str) -> aws_cdk.core.CfnOutput:
+    def get_output(self, logical_id: builtins.str) -> _aws_cdk_core_f4b25747.CfnOutput:
         '''Returns the CfnOutput object from the 'Outputs' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -607,14 +595,15 @@ class CfnInclude(
         :param logical_id: the name of the output to retrieve.
         '''
         if __debug__:
-            def stub(logical_id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ab7eee5c7f3c872ccd683ae10076118756e8f70c7093e76a8d63c120293ea5e4)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
-        return typing.cast(aws_cdk.core.CfnOutput, jsii.invoke(self, "getOutput", [logical_id]))
+        return typing.cast(_aws_cdk_core_f4b25747.CfnOutput, jsii.invoke(self, "getOutput", [logical_id]))
 
     @jsii.member(jsii_name="getParameter")
-    def get_parameter(self, parameter_name: builtins.str) -> aws_cdk.core.CfnParameter:
+    def get_parameter(
+        self,
+        parameter_name: builtins.str,
+    ) -> _aws_cdk_core_f4b25747.CfnParameter:
         '''Returns the CfnParameter object from the 'Parameters' section of the included template.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -625,14 +614,15 @@ class CfnInclude(
         :param parameter_name: the name of the parameter to retrieve.
         '''
         if __debug__:
-            def stub(parameter_name: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9e99811ea229129b46b10e08a7a66a93ea766f59ba1332ccce1e64f4b45022da)
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
-        return typing.cast(aws_cdk.core.CfnParameter, jsii.invoke(self, "getParameter", [parameter_name]))
+        return typing.cast(_aws_cdk_core_f4b25747.CfnParameter, jsii.invoke(self, "getParameter", [parameter_name]))
 
     @jsii.member(jsii_name="getResource")
-    def get_resource(self, logical_id: builtins.str) -> aws_cdk.core.CfnResource:
+    def get_resource(
+        self,
+        logical_id: builtins.str,
+    ) -> _aws_cdk_core_f4b25747.CfnResource:
         '''Returns the low-level CfnResource from the template with the given logical ID.
 
         Any modifications performed on that resource will be reflected in the resulting CDK template.
@@ -650,14 +640,12 @@ class CfnInclude(
         :param logical_id: the logical ID of the resource in the CloudFormation template file.
         '''
         if __debug__:
-            def stub(logical_id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__93208b7203cebcef1fa9f571222ea54df52ca58042bec07fd8dd5cb50ab82b53)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
-        return typing.cast(aws_cdk.core.CfnResource, jsii.invoke(self, "getResource", [logical_id]))
+        return typing.cast(_aws_cdk_core_f4b25747.CfnResource, jsii.invoke(self, "getResource", [logical_id]))
 
     @jsii.member(jsii_name="getRule")
-    def get_rule(self, rule_name: builtins.str) -> aws_cdk.core.CfnRule:
+    def get_rule(self, rule_name: builtins.str) -> _aws_cdk_core_f4b25747.CfnRule:
         '''Returns the CfnRule object from the 'Rules' section of the CloudFormation template with the given name.
 
         Any modifications performed on that object will be reflected in the resulting CDK template.
@@ -668,11 +656,9 @@ class CfnInclude(
         :param rule_name: the name of the Rule in the CloudFormation template.
         '''
         if __debug__:
-            def stub(rule_name: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__48eee6dc74dc264a4c970bb8d086f1011d13ca50be72b14d47b3d50167442648)
             check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
-        return typing.cast(aws_cdk.core.CfnRule, jsii.invoke(self, "getRule", [rule_name]))
+        return typing.cast(_aws_cdk_core_f4b25747.CfnRule, jsii.invoke(self, "getRule", [rule_name]))
 
     @jsii.member(jsii_name="loadNestedStack")
     def load_nested_stack(
@@ -680,7 +666,7 @@ class CfnInclude(
         logical_id: builtins.str,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[builtins.str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> "IncludedNestedStack":
@@ -700,16 +686,7 @@ class CfnInclude(
         :return: the same {@link IncludedNestedStack} object that {@link getNestedStack} returns for this logical ID
         '''
         if __debug__:
-            def stub(
-                logical_id: builtins.str,
-                *,
-                template_file: builtins.str,
-                load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[str, typing.Any]]]] = None,
-                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
-                preserve_logical_ids: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__04d1cbbba7e43a3b6b1fb8b1221a4774f9456c0de52ce500a517f75a54396ea1)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         nested_stack_props = CfnIncludeProps(
             template_file=template_file,
@@ -736,7 +713,7 @@ class CfnIncludeProps:
         self,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[builtins.str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -761,20 +738,12 @@ class CfnIncludeProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                template_file: builtins.str,
-                load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[str, typing.Any]]]] = None,
-                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
-                preserve_logical_ids: typing.Optional[builtins.bool] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6d91be4b5ebdd2a0b22442e458721e46776a703286cd2130d5a8f1928a38333c)
             check_type(argname="argument template_file", value=template_file, expected_type=type_hints["template_file"])
             check_type(argname="argument load_nested_stacks", value=load_nested_stacks, expected_type=type_hints["load_nested_stacks"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
             check_type(argname="argument preserve_logical_ids", value=preserve_logical_ids, expected_type=type_hints["preserve_logical_ids"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "template_file": template_file,
         }
         if load_nested_stacks is not None:
@@ -864,7 +833,7 @@ class IncludedNestedStack:
         self,
         *,
         included_template: CfnInclude,
-        stack: aws_cdk.core.NestedStack,
+        stack: _aws_cdk_core_f4b25747.NestedStack,
     ) -> None:
         '''The type returned from {@link CfnInclude.getNestedStack}. Contains both the NestedStack object and CfnInclude representations of the child stack.
 
@@ -883,16 +852,10 @@ class IncludedNestedStack:
             child_template = included_child_stack.included_template
         '''
         if __debug__:
-            def stub(
-                *,
-                included_template: CfnInclude,
-                stack: aws_cdk.core.NestedStack,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__122f65bf630474418ab80b6e6d19758d8ea5d4afa18a0e74a2f2edd6cdb33e53)
             check_type(argname="argument included_template", value=included_template, expected_type=type_hints["included_template"])
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "included_template": included_template,
             "stack": stack,
         }
@@ -905,11 +868,11 @@ class IncludedNestedStack:
         return typing.cast(CfnInclude, result)
 
     @builtins.property
-    def stack(self) -> aws_cdk.core.NestedStack:
+    def stack(self) -> _aws_cdk_core_f4b25747.NestedStack:
         '''The NestedStack object which represents the scope of the template.'''
         result = self._values.get("stack")
         assert result is not None, "Required property 'stack' is missing"
-        return typing.cast(aws_cdk.core.NestedStack, result)
+        return typing.cast(_aws_cdk_core_f4b25747.NestedStack, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -930,3 +893,92 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__2f3bb4e628f0f7d9dc75fd726d376ac771922ab3819ff8f99c9ddb68dd59f12d(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    template_file: builtins.str,
+    load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[builtins.str, typing.Any]]]] = None,
+    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+    preserve_logical_ids: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1f5a0c7f41eaa1a8f191291aa9de40c89d46ac733246c896e86e480269324f97(
+    condition_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__35991c2bf1db192aae4fc779c6651fae41c9f8fba40faebafd3294897a859c65(
+    hook_logical_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0f696ec50b8ce04c683df8ddfd925f5b0ffce9afb6ec36455ec2b0aca689f501(
+    mapping_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f03477ec6b0fd7fb319f4bc742a91b8f1834203a87e61e19a049e71c55252915(
+    logical_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ab7eee5c7f3c872ccd683ae10076118756e8f70c7093e76a8d63c120293ea5e4(
+    logical_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9e99811ea229129b46b10e08a7a66a93ea766f59ba1332ccce1e64f4b45022da(
+    parameter_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__93208b7203cebcef1fa9f571222ea54df52ca58042bec07fd8dd5cb50ab82b53(
+    logical_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__48eee6dc74dc264a4c970bb8d086f1011d13ca50be72b14d47b3d50167442648(
+    rule_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__04d1cbbba7e43a3b6b1fb8b1221a4774f9456c0de52ce500a517f75a54396ea1(
+    logical_id: builtins.str,
+    *,
+    template_file: builtins.str,
+    load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[builtins.str, typing.Any]]]] = None,
+    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+    preserve_logical_ids: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6d91be4b5ebdd2a0b22442e458721e46776a703286cd2130d5a8f1928a38333c(
+    *,
+    template_file: builtins.str,
+    load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[builtins.str, typing.Any]]]] = None,
+    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+    preserve_logical_ids: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__122f65bf630474418ab80b6e6d19758d8ea5d4afa18a0e74a2f2edd6cdb33e53(
+    *,
+    included_template: CfnInclude,
+    stack: _aws_cdk_core_f4b25747.NestedStack,
+) -> None:
+    """Type checking stubs"""
+    pass
