@@ -55,6 +55,7 @@ import aws_cdk.aws_codestar._jsii
 import aws_cdk.aws_codestarconnections._jsii
 import aws_cdk.aws_codestarnotifications._jsii
 import aws_cdk.aws_cognito._jsii
+import aws_cdk.aws_comprehend._jsii
 import aws_cdk.aws_config._jsii
 import aws_cdk.aws_connect._jsii
 import aws_cdk.aws_connectcampaigns._jsii
@@ -109,6 +110,7 @@ import aws_cdk.aws_identitystore._jsii
 import aws_cdk.aws_imagebuilder._jsii
 import aws_cdk.aws_inspector._jsii
 import aws_cdk.aws_inspectorv2._jsii
+import aws_cdk.aws_internetmonitor._jsii
 import aws_cdk.aws_iot._jsii
 import aws_cdk.aws_iot1click._jsii
 import aws_cdk.aws_iotanalytics._jsii
@@ -121,8 +123,10 @@ import aws_cdk.aws_iotthingsgraph._jsii
 import aws_cdk.aws_iottwinmaker._jsii
 import aws_cdk.aws_iotwireless._jsii
 import aws_cdk.aws_ivs._jsii
+import aws_cdk.aws_ivschat._jsii
 import aws_cdk.aws_kafkaconnect._jsii
 import aws_cdk.aws_kendra._jsii
+import aws_cdk.aws_kendraranking._jsii
 import aws_cdk.aws_kinesis._jsii
 import aws_cdk.aws_kinesisanalytics._jsii
 import aws_cdk.aws_kinesisanalyticsv2._jsii
@@ -156,6 +160,7 @@ import aws_cdk.aws_networkfirewall._jsii
 import aws_cdk.aws_networkmanager._jsii
 import aws_cdk.aws_nimblestudio._jsii
 import aws_cdk.aws_oam._jsii
+import aws_cdk.aws_omics._jsii
 import aws_cdk.aws_opensearchserverless._jsii
 import aws_cdk.aws_opensearchservice._jsii
 import aws_cdk.aws_opsworks._jsii
@@ -198,6 +203,7 @@ import aws_cdk.aws_servicecatalogappregistry._jsii
 import aws_cdk.aws_servicediscovery._jsii
 import aws_cdk.aws_ses._jsii
 import aws_cdk.aws_signer._jsii
+import aws_cdk.aws_simspaceweaver._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sqs._jsii
 import aws_cdk.aws_ssm._jsii
@@ -207,9 +213,11 @@ import aws_cdk.aws_sso._jsii
 import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.aws_supportapp._jsii
 import aws_cdk.aws_synthetics._jsii
+import aws_cdk.aws_systemsmanagersap._jsii
 import aws_cdk.aws_timestream._jsii
 import aws_cdk.aws_transfer._jsii
 import aws_cdk.aws_voiceid._jsii
+import aws_cdk.aws_vpclattice._jsii
 import aws_cdk.aws_waf._jsii
 import aws_cdk.aws_wafregional._jsii
 import aws_cdk.aws_wafv2._jsii
@@ -221,9 +229,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/cloudformation-include",
-    "1.186.1",
+    "1.199.0",
     __name__[0:-6],
-    "cloudformation-include@1.186.1.jsii.tgz",
+    "cloudformation-include@1.199.0.jsii.tgz",
 )
 
 __all__ = [
